@@ -1,47 +1,47 @@
 $VAR1 = {
-          'version' => '0.83',
-          'uploads' => {
-                         'chmod' => 438,
-                         'maxlength' => 21000000,
-                         'path' => '/var/www/htdocs/download'
-                       },
-          'admin' => {
-                       'password' => 'testpass',
-                       'email' => 'your@email.org'
-                     },
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'mod' => 'n',
           'database' => {
-                          'host' => 'localhost',
                           'CurrentPass' => '',
-                          'password' => '',
+                          'user' => 'root',
+                          'host' => 'localhost',
+                          'name' => 'LZE',
                           'CurrentUser' => 'root',
                           'CurrentDb' => 'LZE',
-                          'name' => 'LZE',
-                          'user' => 'root',
+                          'password' => '',
                           'CurrentHost' => 'localhost'
                         },
-          'floodtime' => 10,
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'cgi' => {
-                     'serverName' => 'localhost',
-                     'alias' => 'perl',
-                     'style' => 'mysql',
-                     'title' => 'MySQL::Admin',
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'expires' => '+1y',
-                     'bin' => '/var/www/cgi-bin',
-                     'cookiePath' => '/'
-                   },
-          'mod' => 0,
-          'language' => 'en',
-          'config' => '/var/www/cgi-bin/config/settings.pl',
           'files' => {
+                       'owner' => 'lze',
                        'chmod' => '0755',
-                       'group' => 'lze',
-                       'owner' => 'lze'
+                       'group' => 'lze'
                      },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'scriptAlias' => 'perl'
+          'floodtime' => 10,
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
+          'admin' => {
+                       'email' => 'your@email.org',
+                       'password' => 'testpass'
+                     },
+          'language' => 'en',
+          'cgi' => {
+                     'expires' => '+1y',
+                     'bin' => 'cgi-bin',
+                     'cookiePath' => '/',
+                     'serverName' => 'localhost',
+                     'DocumentRoot' => 'htdocs',
+                     'style' => 'mysql',
+                     'alias' => 'cgi-bin',
+                     'title' => 'MySQL::Admin'
+                   },
+          'scriptAlias' => 'cgi-bin',
+          'uploads' => {
+                         'maxlength' => 21000000,
+                         'chmod' => 438,
+                         'path' => '/var/www/htdocs/download'
+                       },
+          'actions' => 'cgi-bin/config/actions.pl',
+          'config' => 'cgi-bin/config/settings.pl',
+          'translate' => 'cgi-bin/config/translate.pl',
+          'session' => 'cgi-bin/config/session.pl',
+          'version' => '0.84'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
