@@ -1,4 +1,3 @@
-
 function init()
 {
   loadPage('xml/action.xml','xsl/action.xsl','tab');
@@ -168,7 +167,6 @@ function loadPage(inXml,inXsl,outId,tabId,title)
   disableOutputEscaping('content');
 
 }
-
 function markInput(bool)
 {
   var body  = document.getElementsByTagName("body")[0];
@@ -189,7 +187,6 @@ function markTables(bool)
   visible (bool ? 'umarkAll2' : 'markAll2' );
   hide (bool ? 'markAll2' : 'umarkAll2' );
 }
-
 var nCurrentShown;
 function DisplayTable(id)
 {
@@ -197,7 +194,6 @@ function DisplayTable(id)
   visible(id);
   nCurrentShown = id;
 }
-
 var aCurrentShown = new Array();
 function DisplayTables(i,id)
 {
@@ -205,7 +201,6 @@ function DisplayTables(i,id)
     aCurrentShown[i] = id;
     visible(id);
 }
-
 function setIndexType(type)
 {
     if(type == 'FOREIGN KEY')
@@ -287,7 +282,7 @@ function showPopup(id,hideCloseButton)
     else
       visible('closeButton');
     tmpTxt = getText(id);
-    tmpID = id;popupTitle
+    tmpID = id;
     setText(id,'');
     setText('popupTitle',translate(id));
     setText('popupContent',tmpTxt);
@@ -302,13 +297,12 @@ function closePopup()
 }
 var currentId, currentTxt;
 var act ='save';
-function submitForm(node,tabId,tabTitle,bHistory,method)
+function submitForm(node,tabId,tabTitle,bHistory,method,uri)
 {
     bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
     method   = typeof method   !== 'undefined' ? method   : 'POST';
-
+    var url  = typeof uri      !== 'undefined' ? uri      : "%ALIAS%/mysql.pl?";
     if(checkForm(node)){
-      var url = "../perl/mysql.pl?";
       var formData = new FormData();
       for(var i =0; i < node.elements.length;i++){
 	if(node.elements[i].type == 'checkbox' || node.elements[i].type == 'radio'){
@@ -344,22 +338,20 @@ function submitForm(node,tabId,tabTitle,bHistory,method)
 	    url += node.elements[i].name+"="+encodeURIComponent(node.elements[i].value)+"&"; 
 	}
       }
-//       formData.append("MAX_FILE_SIZE","100000");
+//    formData.append("MAX_FILE_SIZE","100000");
       requestURI(url,tabId,tabTitle,bHistory,formData,method);
-      
   }
 }
 var http_request = false;
 var oldpage;
-//requestURI('perl/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
+//requestURI('%ALIAS%/mysql.pl?action=loadSidebar',action,action,false,false,'GET',false)
 function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 {
       closePopup();
-//       if(txt)
-// 	window.document.title = txt;
+      if(txt)
+	window.document.title = txt;
       bHistory = typeof bHistory !== 'undefined' ? bHistory : true;
       method   = typeof method   !== 'undefined' ? method   : 'GET';
-      bWaid    = typeof bWaid     == 'undefined' ? false : false;
       if(bHistory && method == 'GET')
 	history.pushState(null, '','?'+url);
       if( bWaid )
@@ -394,7 +386,7 @@ function requestURI(url,id,txt,bHistory,formData,method,bWaid)
 	http_request.open('GET', url, true);
 	http_request.send(null);
       }else{
-	http_request.open('POST', "../perl/mysql.pl?", true);
+	http_request.open('POST', url, true);
 	http_request.setRequestHeader("Content-Type", "multipart/form-data");
 	http_request.send(formData);
       }
@@ -432,15 +424,26 @@ function setContent()
 	    setText(outID,txt);
 	    evalId(outID);
 	  }
-	}else{
-	    setText('content',oldpage);
-	    setCurrentTab(currentId, currentTxt);
-      }
+	}
+	else
+	{
+	    if(oldpage.length > 0){
+		setText('content',oldpage);
+		setCurrentTab(currentId, currentTxt);
+	    }else{
+	      alert(http_request.status + " " +http_request.responseText);
+	      confirm2(http_request.responseText,errorMessage)
+	    }
+	      
+	}
       var closeButton = $("closeButton");
-      if(!document.cookie.match('sid') || document.cookie.match('sid=123') ){
+      if((!document.cookie.match('sid') || document.cookie.match('sid=123'))  && window.location.search.match('mysql.pl')  )
+      {
 	showPopup('login',true);
 	evalId('popupContent');
-      }else{
+      }
+      else
+      {
 	closeButton.addEventListener ('click',closePopup);
       }
       hide('toolbarcontent2');
@@ -452,6 +455,10 @@ function setContent()
     }
 }
 
+function errorMessage(text){
+   location.href = "install.html";
+}
+
 function evalId(id)
 {
     var content  = $(id);
@@ -475,24 +482,34 @@ function loadHistory()
     var uri = RegExp.$1;
     var url = window.location.search;
     if(uri && action){
-	requestURI('perl/mysql.pl'+uri,action,action,false);
+	requestURI('%ALIAS%/mysql.pl'+uri,action,action,false);
     }else
-      requestURI('perl/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
+      requestURI('%ALIAS%/mysql.pl?action=showDatabases','ShowDatabases','Datenbanken');
     return true;
 }
 
 function translate(string)
 {
 	var lng = navigator.language.indexOf("de") > -1 ? 'de':'en';
-        var l = new Lang(); 
-	if(string){
-	  var ret = eval('l.'+lng+string.toLowerCase());
-	  return ret ? ret : string;
-	} else{
-	  traversTranslate('tab1',lng,l);
-	  traversTranslate('tabwidget',lng,l);
+	if(typeof Lang != 'undefined')
+	{
+	  var l = new Lang(); 
+	  if(string){
+	    var ret = eval('l.'+lng+string.toLowerCase());
+	    return ret ? ret : string;
+	  }
+	  else
+	  {
+	    traversTranslate('tab1',lng,l);
+	    traversTranslate('tabwidget',lng,l);
+	  }
+	}
+	else
+	{
+	  return string;
 	}
 }
+
 function traversTranslate(id,lng,l)
 {
     if($(id)){
@@ -524,11 +541,14 @@ var oldTime;
 function breakOut()
 {
   clickA = clickA ?false:true;
-  if(clickA){
+  if(clickA)
+  {
     oldDate = new Date();
     oldTime = oldDate.getTime();
     return false;
-  }else{
+  }
+  else
+  {
     var date = new Date();
     var time = date.getTime();
     return (time - oldTime > 1000) ? false : true;
@@ -640,7 +660,6 @@ function showToolbar(id){
     });
   }
 }
-
 function hideToolbar(id){
   var entry = $(id);
   if(entry && entry.firstChild){
